@@ -44,7 +44,7 @@ class Cursor(pymongo.cursor.Cursor):
         if isinstance(index, slice):
             # pymongo will return an iterator, so next will be called.
             return super(Cursor, self).__getitem__(index)
-        elif isinstance(index, (int, long)):
+        elif isinstance(index, int):
             # get a particular item by index
             document = super(Cursor, self).__getitem__(index)
             model_instance = self._model_class.inflate(document)
@@ -72,7 +72,6 @@ class Collection(pymongo.collection.Collection):
         if document:
             model_instance = self._model_class.inflate(document)
             return model_instance
-        return None
 
 
 class AttrDict(dict):
@@ -96,16 +95,19 @@ class AttrDict(dict):
             self[key] = other[key]
 
     def setdefault(self, key, value=None):
-        if key not in self:  # ... uh... python's default behavior is weird
+        if key not in self:
             self[key] = value
         return self[key]
 
-    def __getattr__(self, attr):
-        """Access items with dot notation"""
+    def __getattribute__(self, attr):
+        """Access items with dot notation."""
         try:
-            return super(AttrDict, self).__getitem__(attr)
-        except KeyError as e:
-            raise AttributeError(e)  # it was accessed as an attribute!
+            return object.__getattribute__(self, attr)
+        except AttributeError as attr_error:
+            try:
+                return super(AttrDict, self).__getitem__(attr)
+            except KeyError:
+                raise attr_error
 
     def __setattr__(self, attr, value):
         """Set items with dot notation"""
@@ -114,10 +116,7 @@ class AttrDict(dict):
         for cls in self.__class__.__mro__ + (self,):
             if attr in cls.__dict__:
                 return object.__setattr__(self, attr, value)
-        try:
-            self[attr] = value
-        except KeyError as e:
-            raise AttributeError(e)  # it was accessed as an attribute!
+        self[attr] = value
 
     def __delattr__(self, key):
         """Delete items with dot notation"""
@@ -181,6 +180,10 @@ class Model(AttrDict):
         if '_id' in self:
             return self.collection.remove({'_id': self.pop('_id')})
 
+    def is_in_db(self):
+        """Does this instance have a record in the database?"""
+        return '_id' in self
+
     @classmethod
     def inflate(cls, json):
         """Return a model instance given its MongoDB json representation"""
